pychemia.core.tests package
===========================

.. automodule:: pychemia.core.tests
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

pychemia.core.tests.test_core module
------------------------------------

.. automodule:: pychemia.core.tests.test_core
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.core.tests.test_doctest module
---------------------------------------

.. automodule:: pychemia.core.tests.test_doctest
    :members:
    :undoc-members:
    :show-inheritance:


